Module module

Module module 

Structs

ArchivedBuildInfo
An archived BuildInfo
ArchivedFlatModule
An archived FlatModule
BuildInfo
BuildInfoResolver
The resolver for an archived BuildInfo
FlatModule
Flatten module so that it can be serialized.
FlatModuleResolver
The resolver for an archived FlatModule
FrozenModule
Module
A finished module that stores all the vector items. The vector items shares the underlying data. The vector items are flattened and ready to be serialized.
ModuleView

Enums

ArchivedModuleMetadata
An archived ModuleMetadata
ArchivedPageMetadata
An archived PageMetadata
ModuleMetadata
metadata that can be attached to a module.
ModuleMetadataResolver
The resolver for an archived ModuleMetadata
PageMetadata
metadata that can be attached to a module.
PageMetadataResolver
The resolver for an archived PageMetadata

Traits

ModuleStream
Trait of a streaming representation of a module.
ToItemMap

Type Aliases

ItemMap
RefItemMap
RefItemMapSync
RefItemMapT