reflexo_typst2vec::convert

Struct DefId

pub struct DefId(pub u64);
The local id of a svg item. This id is only unique within the svg document.

Tuple Fields

0: u64

Implementations

Source

impl DefId

pub fn as_svg_id(self, prefix: &'static str) -> String

Create a xml id from the given prefix and the def id of this reference. Note that the def id may not be stable across compilation. Note that the entire html document shares namespace for ids.