Type Alias SpanId

pub type SpanId = u64;
A span location in the source code. Note: it is unsafe to transfer a span across processes. Note: a span id is only ensured correct within the same compilation lifespan.