Module debug_loc

Structs

CharPosition
A char position represented in form of line and column. The position is encoded in Utf-8 or Utf-16, and the encoding is determined by usage.
CharRange
DocumentPosition
A serializable physical position in a document.
ElementPoint
A point on the element tree.
FileLocation
A resolved source (text) location.
FlatSourceLocation
A flat resolved source (text) location.
FsDataSource
A file system data source.
MemoryDataSource
A in-memory data source.
SourceLocation
A resolved source (text) location.
SourceRange
SourceSpanOffset
Unevaluated source span with offset.
TypstPosition
A physical position in a document.

Enums

DataSource
Data source for a document.

Type Aliases

RawSourceSpan
Raw representation of a source span.
SourceSpan
Unevaluated source span. The raw source span is unsafe to serialize and deserialize. Because the real source location is only known during liveness of the compiled document.