Type Alias reflexo_typst2vec::debug_loc::SourceSpan

source ·
pub type SourceSpan = Span;
Unevaluated source span. The raw source span is unsafe to serialize and deserialize. Because the real source location is only known during liveness of the compiled document.

Aliased Type

struct SourceSpan(/* private fields */);