Module font

Structs

DummyFontGlyphProvider
The dummy IGlyphProvider implementation. It performs no operation and always returns None.
FontGlyphProvider
The default IGlyphProvider implementation. It uses the local font data to extract the glyph data.
GlyphId
A type-safe wrapper for glyph ID.
GlyphProvider

Traits

IGlyphProvider
IGlyphProvider extracts the font data from the font. Note (Possibly block unsafe): If a Font is dummy (lazy loaded), it will block current thread and fetch the font data from the server.