reflexo_typst2vec

Module hash

Structs

Traits

Functions

  • A convenience function for when you need a quick 32-bit hash.
  • A convenience function for when you need a quick 64-bit hash.
  • Calculate a 128-bit siphash of a value. Currently, this function use SipHasher13 as the underlying hash algorithm.
  • This function provides a hash function for items, which also includes a type id as part of the hash. Note: This function is not stable across different versions of typst-ts, so it is preferred to be always used in memory. Currently, this function use SipHasher13 as the underlying hash algorithm.
  • This function maintain hash function corresponding to Typst Typst changed the hash function from siphasher::sip128::SipHasher to siphasher::sip128::SipHasher13 since commit https://github.com/typst/typst/commit/d0afba959d18d1c2c646b99e6ddd864b1a91deb2 Commit log: This seems to significantly improves performance. Inspired by rust-lang/rust#107925

Type Aliases