pub struct Fingerprint { /* private fields */ }Expand description
See https://github.com/rust-lang/rust/blob/master/compiler/rustc_hir/src/stable_hash_impls.rs#L22 The fingerprint conflicts should be very rare and should be handled by the compiler.
That being said, given a high quality hash function, the collision probabilities in question are very small. For example, for a big crate like
rustc_middle(with ~50000LocalDefIds as of the time of writing) there is a probability of roughly 1 in 14,750,000,000 of a crate-internal collision occurring. For a big crate graph with 1000 crates in it, there is a probability of 1 in 36,890,000,000,000 of aStableCrateIdcollision.
This stores the 16-bytes data in a pair of u64 instead of single u128 to
avoid heavily affecting align of the embedding structs.
Implementations
Sourceimpl Fingerprint
impl Fingerprint
Sourcepub fn from_pair(lo: u64, hi: u64) -> Fingerprint
pub fn from_pair(lo: u64, hi: u64) -> Fingerprint
Creates a new fingerprint from the given pair of 64-bit integers.
Sourcepub const fn from_u128(hash: u128) -> Fingerprint
pub const fn from_u128(hash: u128) -> Fingerprint
Creates a new fingerprint from the given 128-bit integer.
Sourcepub fn lower32(self) -> u32
pub fn lower32(self) -> u32
Cuts the fingerprint into a 32-bit integer.
It could be used as a hash value if the fingerprint is calculated from a stable hash function, otherwise, the result has pool quality.
Sourcepub fn try_from_str(s: &str) -> Result<Fingerprint, Error>
pub fn try_from_str(s: &str) -> Result<Fingerprint, Error>
Creates a new Fingerprint from a svg id that doesn’t have prefix.