Module incr

Module incr 

Structs

IncrDocClient
Client side implementation is free from typst details. maintains the data of the incremental rendering at client side
IncrDocClientKern
Client side implementation is free from typst details.
IncrDocServer
maintains the data of the incremental rendering at server side