A virtual machine that diffs and renders a frame.
This is a stateful object that is used to render a frame.
The ’m lifetime is the lifetime of the module which stores the frame data.
A virtual machine for rendering a frame.
This is a stateful object that is used to render a frame.
The ’m lifetime is the lifetime of the module which stores the frame data.