reflexo_typst2vec::vm

Trait IncrRenderVm

pub trait IncrRenderVm<'m>: Sized + RenderVm<'m>
where Self::Group: IncrGroupContext<Self>,
{ // Provided methods fn render_diff_item( &mut self, next_abs_ref: &Fingerprint, prev_abs_ref: &Fingerprint, ) -> Self::Resultant { ... } fn render_diff_group( &mut self, group_ctx: &mut Self::Group, prev_item_: Option<&VecItem>, next: &GroupRef, ) { ... } fn render_diff_transformed_item( &mut self, ts: &mut Self::Group, prev_item_: Option<&VecItem>, transformed: &TransformedRef, ) { ... } fn render_diff_text( &mut self, group_ctx: Self::Group, next_abs_ref: &Fingerprint, _prev_abs_ref: &Fingerprint, text: &TextItem, ) -> Self::Group { ... } }
A virtual machine that diffs and renders a frame. This is a stateful object that is used to render a frame. The ’m lifetime is the lifetime of the module which stores the frame data.

Provided Methods

fn render_diff_item( &mut self, next_abs_ref: &Fingerprint, prev_abs_ref: &Fingerprint, ) -> Self::Resultant

Render an item into the a <g/> element.

fn render_diff_group( &mut self, group_ctx: &mut Self::Group, prev_item_: Option<&VecItem>, next: &GroupRef, )

Render a frame group into underlying context.

fn render_diff_transformed_item( &mut self, ts: &mut Self::Group, prev_item_: Option<&VecItem>, transformed: &TransformedRef, )

Render a transformed frame into underlying context.

fn render_diff_text( &mut self, group_ctx: Self::Group, next_abs_ref: &Fingerprint, _prev_abs_ref: &Fingerprint, text: &TextItem, ) -> Self::Group

Render a diff text into the underlying context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors