reflexo_typst2vec

Module convert

Modules

Structs

Enums

Traits

Functions

  • Create a xml id from the given prefix and the def id of this reference. Note that the def id may not be stable across compilation. Note that the entire html document shares namespace for ids.

Type Aliases