Modules
Structs
- A stable absolute reference. The fingerprint is used to identify the item and likely unique between different svg documents. The (local) def id is only unique within the svg document.
- The resolver for an archived
AbsoluteRef - An archived
AbsoluteRef - An archived
Axes - An archived
BuildInfo - An archived
Color32Item - An archived
ColorTransform - An archived
DefId - An archived
FlatModule - An archived
FontItem - An archived
FontRef - An archived
GlyphRef - An archived
GradientItem - An archived
GroupRef - An archived
HtmlItem - An archived
Image - An archived
ImageGlyphItem - An archived
ImageItem - An archived
IncrFontPack - An archived
IncrGlyphPack - An archived
ItemPack - An archived
LayoutRegionRepr - An archived
LayoutSourceMapping - An archived
LinkItem - An archived
OutlineGlyphItem - An archived
Page - An archived
PathItem - An archived
PatternItem - An archived
Rgba8Item - An archived
Scalar - An archived
TextItem - An archived
TextItemContent - An archived
TextShape - An archived
Transform - An archived
TransformedRef - A container with a horizontal and vertical component.
- The resolver for an archived
Axes - The resolver for an archived
BuildInfo - A 32-bit color in a specific color space. Note: some backends may not support 32-bit colors.
- The resolver for an archived
Color32Item - The resolver for an archived
ColorTransform - The local id of a svg item. This id is only unique within the svg document.
- The resolver for an archived
DefId - Flatten module so that it can be serialized.
- The resolver for an archived
FlatModule - Reference a font item in a more friendly format to compress and store information. The fonts are locally stored in the svg module. With a font reference, we can get both the font metric and the font data. The
font_hashis to let it safe to be cached. By estimation, https://stackoverflow.com/a/29628053/9323228 If the hash algorithm forfont_hashis good enough. When you have about 500 fonts (in windows), the collision rate is about: - The resolver for an archived
FontItem - Reference a font item in a more friendly format to compress and store information, similar to
GlyphRef. - The resolver for an archived
FontRef - Reference a glyph item in a more friendly format to compress and store information. The glyphs are locally stored in the svg module. With a glyph reference, we can get both the font metric and the glyph data. The
font_hashis to let it safe to be cached, please seecrate::vector::ir::FontItemfor more details. - The resolver for an archived
GlyphRef - Item representing an
<gradient/>element. - The resolver for an archived
GradientItem - References to a group of items with translates. Absolute positioning items at their corresponding points.
- The resolver for an archived
GroupRef - Item representing an
<image/>element. - The resolver for an archived
HtmlItem - Data of an
<image/>element. - A image glyph item.
- The resolver for an archived
ImageGlyphItem - Item representing an
<image/>element. - The resolver for an archived
ImageItem - The resolver for an archived
Image - Flatten mapping fingerprints to glyph items.
- The resolver for an archived
IncrFontPack - Flatten mapping fingerprints to glyph items.
- The resolver for an archived
IncrGlyphPack - References to a set of items.
- The resolver for an archived
ItemPack - Describing
- The resolver for an archived
LayoutRegionRepr - The resolver for an archived
LayoutSourceMapping - Item representing an
<a/>element. - The resolver for an archived
LinkItem - A finished module that stores all the vector items. The vector items shares the underlying data. The vector items are flattened and ready to be serialized.
- Module with multiple documents, corresponding to multiple
typst::model::Documentrearranged byLayoutRegion. - An outline glyph item.
- The resolver for an archived
OutlineGlyphItem - References to a page frame.
- The resolver for an archived
Page - Item representing an
<path/>element. - The resolver for an archived
PathItem - Item representing an
<pattern/>element. - The resolver for an archived
PatternItem - Item representing an 8-bit color item.
- The resolver for an archived
Rgba8Item - Scalar value of Vector representation. Note: Unlike Typst’s Scalar, all lengths with Scalar type are in pt.
- The resolver for an archived
Scalar - A text item. Item representing an
<g><text/><g/>element. - The content metadata of a
TextItem. - The resolver for an archived
TextItemContent - The resolver for an archived
TextItem - The shape metadata of a
TextItem. - The resolver for an archived
TextShape - A scale-skew-translate transformation.
- The resolver for an archived
Transform - References to a vec item with transform. Item representing an
<g/>element applied with aTransformItem. - The resolver for an archived
TransformedRef - Module with page references, corresponding to a
typst::model::Document.
Enums
- An archived
ColorSpace - An archived
FlatGlyphItem - An archived
GradientKind - An archived
GradientStyle - An archived
LayoutRegion - An archived
LayoutRegionNode - An archived
ModuleMetadata - An archived
PageMetadata - An archived
PathStyle - An archived
SourceMappingNode - An archived
TransformItem - An archived
VecItem - A color space for mixing.
- The resolver for an archived
ColorSpace - The glyph item definition with all of variants of
GlyphItemother thanGlyphItem::Raw, hence it is serializable. - The resolver for an archived
FlatGlyphItem - Kind of gradients for
GradientItem. - The resolver for an archived
GradientKind - Attributes that is applicable to the
GradientItem. - The resolver for an archived
GradientStyle - Describing
- Describing
- The resolver for an archived
LayoutRegionNode - The resolver for an archived
LayoutRegion - metadata that can be attached to a module.
- The resolver for an archived
ModuleMetadata - metadata that can be attached to a module.
- The resolver for an archived
PageMetadata - Attributes that is applicable to the
PathItem. - The resolver for an archived
PathStyle - Source mapping from vec item to source span.
- The resolver for an archived
SourceMappingNode - Item representing all the transform that is applicable to a
super::VecItem. See https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/transform - The resolver for an archived
TransformItem - A vector item that is specialized for representing
typst::model::Documentor its subtypes. - The resolver for an archived
VecItem
Traits
- Trait of a streaming representation of a module.
Functions
- Create a xml id from the given prefix and the def id of this reference. Note that the def id may not be stable across compilation. Note that the entire html document shares namespace for ids.
Type Aliases
- length in pt.
- Angle in radians
- References to a set of fonts.
- References to a set of glyphs.
- Point in (x pt, y pt)
- Ratio within range [0, 1]
- Size in (width pt, height pt)
- A span location in the source code. Note: it is unsafe to transfer a span across processes. Note: a span id is only ensured correct within the same compilation lifespan.