Structs
- An archived
BuildInfo - An archived
FlatModule - The resolver for an archived
BuildInfo - Flatten module so that it can be serialized.
- The resolver for an archived
FlatModule - A finished module that stores all the vector items. The vector items shares the underlying data. The vector items are flattened and ready to be serialized.
Enums
- An archived
ModuleMetadata - An archived
PageMetadata - metadata that can be attached to a module.
- The resolver for an archived
ModuleMetadata - metadata that can be attached to a module.
- The resolver for an archived
PageMetadata
Traits
- Trait of a streaming representation of a module.