Structs
- Char
Position - A char position represented in form of line and column. The position is encoded in Utf-8 or Utf-16, and the encoding is determined by usage.
- Char
Range - Document
Position - A serializable physical position in a document.
- Element
Point - A point on the element tree.
- File
Location - A resolved source (text) location.
- Flat
Source Location - A flat resolved source (text) location.
- FsData
Source - A file system data source.
- Memory
Data Source - A in-memory data source.
- Source
Location - A resolved source (text) location.
- Source
Range - Source
Span Offset - Unevaluated source span with offset.
- Typst
Position - A physical position in a document.
Enums
- Data
Source - Data source for a document.
Type Aliases
- RawSource
Span - Raw representation of a source span.
- Source
Span - Unevaluated source span. The raw source span is unsafe to serialize and deserialize. Because the real source location is only known during liveness of the compiled document.