Structs
- A char position represented in form of line and column. The position is encoded in Utf-8 or Utf-16, and the encoding is determined by usage.
- A serializable physical position in a document.
- A point on the element tree.
- A resolved source (text) location.
- A flat resolved source (text) location.
- A file system data source.
- A in-memory data source.
- A resolved source (text) location.
- Unevaluated source span with offset.
- A physical position in a document.
Enums
- Data source for a document.
Type Aliases
- Raw representation of a source span.
- Unevaluated source span. The raw source span is unsafe to serialize and deserialize. Because the real source location is only known during liveness of the compiled document.