Structs
- The dummy
IGlyphProviderimplementation. It performs no operation and always returnsNone. - The default
IGlyphProviderimplementation. It uses the local font data to extract the glyph data. - A type-safe wrapper for glyph ID.
Traits
- IGlyphProvider extracts the font data from the font. Note (Possibly block unsafe): If a
Fontis dummy (lazy loaded), it will block current thread and fetch the font data from the server.