Module vm

Traits

GroupContext
A RAII trait for rendering vector items into underlying context.
IncrGroupContext
A RAII trait for rendering flatten SVG items into underlying context.
IncrRenderVm
A virtual machine that diffs and renders a frame. This is a stateful object that is used to render a frame. The ’m lifetime is the lifetime of the module which stores the frame data.
RenderVm
A virtual machine for rendering a frame. This is a stateful object that is used to render a frame. The ’m lifetime is the lifetime of the module which stores the frame data.
TransformContext
A build pattern for applying transforms to the group of items. See ir::Transform.