reflexo_typst2vec

Module vm

Traits

  • A RAII trait for rendering vector items into underlying context.
  • A RAII trait for rendering flatten SVG items into underlying context.
  • A virtual machine that diffs and renders a frame. This is a stateful object that is used to render a frame. The ’m lifetime is the lifetime of the module which stores the frame data.
  • A virtual machine for rendering a frame. This is a stateful object that is used to render a frame. The ’m lifetime is the lifetime of the module which stores the frame data.
  • A build pattern for applying transforms to the group of items. See ir::Transform.