pub trait GroupContext<C>: Sized {
Show 16 methods
// Required method
fn render_item_at(
&mut self,
ctx: &mut C,
pos: Axes<Scalar>,
item: &Fingerprint,
);
// Provided methods
fn with_frame(self, _ctx: &mut C, _group: &GroupRef) -> Self { ... }
fn with_text(
self,
_ctx: &mut C,
_text: &TextItem,
_fill_key: &Fingerprint,
) -> Self { ... }
fn with_label(self, _ctx: &mut C, _label: &str) -> Self { ... }
fn with_reuse(self, _ctx: &mut C, _v: &Fingerprint) -> Self { ... }
fn with_text_shape(
&mut self,
_ctx: &mut C,
_upem: Scalar,
_shape: &TextShape,
_fill_key: &Fingerprint,
) { ... }
fn render_path(
&mut self,
_ctx: &mut C,
_path: &PathItem,
_abs_ref: &Fingerprint,
) { ... }
fn render_link(&mut self, _ctx: &mut C, _link: &LinkItem) { ... }
fn render_image(&mut self, _ctx: &mut C, _image_item: &ImageItem) { ... }
fn attach_debug_info(&mut self, _ctx: &mut C, _span_id: u64) { ... }
fn render_content_hint(&mut self, _ctx: &mut C, _ch: char) { ... }
fn render_html(&mut self, _ctx: &mut C, _html: &HtmlItem) { ... }
fn render_html_sized(&mut self, _ctx: &mut C, _html: &SizedRawHtmlItem) { ... }
fn render_item(&mut self, ctx: &mut C, item: &Fingerprint) { ... }
fn render_glyph(
&mut self,
_ctx: &mut C,
_pos: Scalar,
_font: &FontItem,
_glyph_id: u32,
) { ... }
fn render_text_semantics(
&mut self,
_ctx: &mut C,
_text: &TextItem,
_width: Scalar,
) { ... }
}Expand description
A RAII trait for rendering vector items into underlying context.
Required Methods
fn render_item_at(&mut self, ctx: &mut C, pos: Axes<Scalar>, item: &Fingerprint)
Provided Methods
fn with_frame(self, _ctx: &mut C, _group: &GroupRef) -> Self
fn with_text( self, _ctx: &mut C, _text: &TextItem, _fill_key: &Fingerprint, ) -> Self
fn with_label(self, _ctx: &mut C, _label: &str) -> Self
fn with_reuse(self, _ctx: &mut C, _v: &Fingerprint) -> Self
Sourcefn with_text_shape(
&mut self,
_ctx: &mut C,
_upem: Scalar,
_shape: &TextShape,
_fill_key: &Fingerprint,
)
fn with_text_shape( &mut self, _ctx: &mut C, _upem: Scalar, _shape: &TextShape, _fill_key: &Fingerprint, )
attach shape of the text to the node using css rules.
Sourcefn render_path(
&mut self,
_ctx: &mut C,
_path: &PathItem,
_abs_ref: &Fingerprint,
)
fn render_path( &mut self, _ctx: &mut C, _path: &PathItem, _abs_ref: &Fingerprint, )
Render a geometrical shape into underlying context.
Sourcefn render_link(&mut self, _ctx: &mut C, _link: &LinkItem)
fn render_link(&mut self, _ctx: &mut C, _link: &LinkItem)
Render a semantic link into underlying context.
Sourcefn render_image(&mut self, _ctx: &mut C, _image_item: &ImageItem)
fn render_image(&mut self, _ctx: &mut C, _image_item: &ImageItem)
Render an image into underlying context.
fn attach_debug_info(&mut self, _ctx: &mut C, _span_id: u64)
Sourcefn render_content_hint(&mut self, _ctx: &mut C, _ch: char)
fn render_content_hint(&mut self, _ctx: &mut C, _ch: char)
Render a semantic link into underlying context.
Sourcefn render_html(&mut self, _ctx: &mut C, _html: &HtmlItem)
fn render_html(&mut self, _ctx: &mut C, _html: &HtmlItem)
Render a html element into underlying context.
Sourcefn render_html_sized(&mut self, _ctx: &mut C, _html: &SizedRawHtmlItem)
fn render_html_sized(&mut self, _ctx: &mut C, _html: &SizedRawHtmlItem)
Render a sized html element into underlying context.
fn render_item(&mut self, ctx: &mut C, item: &Fingerprint)
fn render_glyph( &mut self, _ctx: &mut C, _pos: Scalar, _font: &FontItem, _glyph_id: u32, )
fn render_text_semantics( &mut self, _ctx: &mut C, _text: &TextItem, _width: Scalar, )
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.